@@ -11,6 +11,7 @@ import getpass
 import hashlib
 import binascii
 import textwrap
+from time import strftime
 from threading import Thread
 
 __all__ = list(globals())
@@ -30,7 +31,7 @@ delete = lambda path: os.remove(path) if os.path.isfile(path) else shutil.rmtree
 
 # data resort
 unique = lambda arr: sorted(set(arr), key=arr.index)
-flatten = lambda arr: sum(arr[1:], arr[0])
+flatten = lambda arr: flatten(sum([list(one) if isinstance(one, (list, tuple)) else [one] for one in arr], [])) if any(isinstance(one, (list, tuple)) for one in arr) else arr
 reshape = lambda arr, width: list(zip(*[iter(arr)]*width))
 transpose = lambda arr: list(zip(*arr))
 
@@ -39,7 +40,12 @@ join = lambda *string, sep='': sep.join(string)
 wash = lambda func, arr: [wash(func, v) for v in arr] if isinstance(arr, (list, tuple)) else func(arr)
 dumps = lambda data: json.dumps(data, ensure_ascii=False, indent=2)
 indent = lambda width, text: textwrap.indent(textwrap.dedent(text)[1:-1], ' ' * width)
-str2dict = lambda text: dict(re.findall(r'(.*?):\s*(.*)', text))
+str2dict = lambda text: dict(re.findall(r'^\s*(.*?)\s*:\s*(.*?)\s*$', text, re.M))
+
+# time stamp
+time = lambda sep='': strftime('%H{0}%M{0}%S').format(sep)
+date = lambda sep='': strftime('%Y{0}%m{0}%d').format(sep)
+stamp = lambda fmt: strftime(re.sub(r'%(.+?)%', lambda m: re.sub(r'([A-Za-z])', r'%\1', m.group(1)), fmt))  # e.g. stamp('folder/%Ymd_HMS%_68.3%%.txt')
 
 # sorting
 sort_kv  = lambda dic, reverse=False: sorted(dic.items(), key=lambda item: item[1], reverse=reverse)
@@ -49,11 +55,11 @@ sort_num = lambda text: [(s, int(n)) for s, n in re.findall(r'(\D+)(\d+)', 'a%s0
 # number convert
 hex2bin = lambda hex: bin(int(hex, 16))[2:].zfill(len(hex) * 4)
 bin2hex = lambda bin: hex(int(bin, 2))[2:].zfill(len(bin) // 4)
-half2hex = lambda num: struct.pack('>e', num).hex()
+half2hex = lambda num: struct.pack('>e', float(num)).hex()
 hex2half = lambda hex: struct.unpack('>e', bytes.fromhex(hex))[0]
-float2hex = lambda num: struct.pack('>f', num).hex()
+float2hex = lambda num: struct.pack('>f', float(num)).hex()
 hex2float = lambda hex: struct.unpack('>f', bytes.fromhex(hex))[0]
-double2hex = lambda num: struct.pack('>d', num).hex()
+double2hex = lambda num: struct.pack('>d', float(num)).hex()
 hex2double = lambda hex: struct.unpack('>d', bytes.fromhex(hex))[0]
 
 # pc tools
